@@ -6,11 +6,12 @@ from unittest import TestCase
 
 from reactives import reactive
 from reactives.collections import ReactiveList, ReactiveDict
+from reactives.factory.type import ReactiveInstance
 from reactives.tests import assert_scope_empty, assert_reactor_called, assert_in_scope, assert_not_reactor_called
 
 
 @reactive
-class _Reactive:
+class _Reactive(ReactiveInstance):
     pass
 
 
@@ -115,17 +116,17 @@ class ReactiveDictTest(TestCase):
     def test_get(self) -> None:
         sut = ReactiveDict(one=1, two=2)
         with assert_in_scope(sut):
-            self.assertEquals(2, sut.get('two'))
+            self.assertEqual(2, sut.get('two'))
 
     def test_items(self) -> None:
         sut = ReactiveDict(one=1, two=2)
         with assert_in_scope(sut):
-            self.assertEquals([('one', 1), ('two', 2)], list(sut.items()))
+            self.assertEqual([('one', 1), ('two', 2)], list(sut.items()))
 
     def test_keys(self) -> None:
         sut = ReactiveDict(one=1, two=2)
         with assert_in_scope(sut):
-            self.assertEquals(['one', 'two'], list(sut.keys()))
+            self.assertEqual(['one', 'two'], list(sut.keys()))
 
     def test_pop(self) -> None:
         reactive_value = _Reactive()
@@ -142,8 +143,8 @@ class ReactiveDictTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 key, value = sut.popitem()
-        self.assertEquals('reactive', key)
-        self.assertEquals(reactive_value, value)
+        self.assertEqual('reactive', key)
+        self.assertEqual(reactive_value, value)
         self.assertCountEqual([], sut)
         self.assertCountEqual([], reactive_value.react._reactors)
 
@@ -153,7 +154,7 @@ class ReactiveDictTest(TestCase):
         with assert_in_scope(sut):
             with assert_not_reactor_called(sut):
                 sut.setdefault('reactive', reactive_value)
-        self.assertNotEquals(reactive_value, dict.get(sut, 'reactive'))
+        self.assertNotEqual(reactive_value, dict.get(sut, 'reactive'))
         self.assertNotIn(sut, reactive_value.react._reactors)
 
     def test_setdefault_with_unknown_key(self) -> None:
@@ -162,7 +163,7 @@ class ReactiveDictTest(TestCase):
         with assert_in_scope(sut):
             with assert_reactor_called(sut):
                 sut.setdefault('reactive', reactive_value)
-        self.assertEquals(reactive_value, dict.get(sut, 'reactive'))
+        self.assertEqual(reactive_value, dict.get(sut, 'reactive'))
         self.assertIn(sut, reactive_value.react._reactors)
 
     def test_update(self) -> None:
@@ -173,7 +174,7 @@ class ReactiveDictTest(TestCase):
                 sut.update({
                     'reactive': reactive_value
                 })
-        self.assertEquals(reactive_value, dict.get(sut, 'reactive'))
+        self.assertEqual(reactive_value, dict.get(sut, 'reactive'))
         self.assertIn(sut, reactive_value.react._reactors)
 
     def test_values(self) -> None:
@@ -199,7 +200,7 @@ class ReactiveDictTest(TestCase):
     def test_eq(self) -> None:
         sut = ReactiveDict(one=1, two=2)
         with assert_in_scope(sut):
-            self.assertEquals({
+            self.assertEqual({
                 'one': 1,
                 'two': 2,
             }, sut)
@@ -207,7 +208,7 @@ class ReactiveDictTest(TestCase):
     def test_getitem(self) -> None:
         sut = ReactiveDict(one=1, two=2)
         with assert_in_scope(sut):
-            self.assertEquals(2, sut['two'])
+            self.assertEqual(2, sut['two'])
 
     def test_iter(self) -> None:
         sut = ReactiveDict(one=1, two=2)
@@ -217,12 +218,12 @@ class ReactiveDictTest(TestCase):
     def test_len(self) -> None:
         sut = ReactiveDict(one=1, two=2)
         with assert_in_scope(sut):
-            self.assertEquals(2, len(sut))
+            self.assertEqual(2, len(sut))
 
     def test_ne(self) -> None:
         sut = ReactiveDict(one=1, two=2)
         with assert_in_scope(sut):
-            self.assertNotEquals({
+            self.assertNotEqual({
                 'two': 1,
                 'one': 2,
             }, sut)
@@ -233,7 +234,7 @@ class ReactiveDictTest(TestCase):
         with assert_in_scope(sut):
             # Because dictionary order isn't guaranteed before Python 3.7, we cannot compare to a hardcoded list of
             # expected keys.
-            self.assertEquals(['two', 'one'], list(reversed(sut)))
+            self.assertEqual(['two', 'one'], list(reversed(sut)))
 
     def test_setitem(self) -> None:
         reactive_value = _Reactive()
@@ -241,7 +242,7 @@ class ReactiveDictTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut['reactive'] = reactive_value
-        self.assertEquals(reactive_value, sut['reactive'])
+        self.assertEqual(reactive_value, sut['reactive'])
         with assert_reactor_called(sut):
             reactive_value.react.trigger()
 
@@ -377,13 +378,13 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut.clear()
-        self.assertEquals([], sut)
-        self.assertEquals([], reactive_value.react._reactors)
+        self.assertEqual([], sut)
+        self.assertEqual([], reactive_value.react._reactors)
 
     def test_count(self) -> None:
         sut = ReactiveList([1, 2, 1])
         with assert_in_scope(sut):
-            self.assertEquals(2, sut.count(1))
+            self.assertEqual(2, sut.count(1))
 
     def test_extend(self) -> None:
         reactive_value1 = _Reactive()
@@ -392,7 +393,7 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut.extend([reactive_value1, reactive_value2])
-        self.assertEquals([1, 2, reactive_value1, reactive_value2], sut)
+        self.assertEqual([1, 2, reactive_value1, reactive_value2], sut)
         with assert_reactor_called(sut):
             reactive_value1.react.trigger()
         with assert_reactor_called(sut):
@@ -401,12 +402,12 @@ class ReactiveListTest(TestCase):
     def test_index_without_slice(self) -> None:
         sut = ReactiveList([1, 2, 1, 2, 1, 2, 1, 2])
         with assert_in_scope(sut):
-            self.assertEquals(1, sut.index(2))
+            self.assertEqual(1, sut.index(2))
 
     def test_index_with_slice(self) -> None:
         sut = ReactiveList([1, 2, 1, 2, 1, 2, 1, 2])
         with assert_in_scope(sut):
-            self.assertEquals(2, sut.index(1, 2, 5))
+            self.assertEqual(2, sut.index(1, 2, 5))
 
     def test_insert(self) -> None:
         reactive_value = _Reactive()
@@ -414,7 +415,7 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut.insert(1, reactive_value)
-        self.assertEquals([1, reactive_value, 2], sut)
+        self.assertEqual([1, reactive_value, 2], sut)
         with assert_reactor_called(sut):
             reactive_value.react.trigger()
 
@@ -424,7 +425,7 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut.pop()
-        self.assertEquals([1, 2], sut)
+        self.assertEqual([1, 2], sut)
         with assert_not_reactor_called(sut):
             reactive_value.react.trigger()
 
@@ -434,7 +435,7 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut.pop(1)
-        self.assertEquals([1, 2], sut)
+        self.assertEqual([1, 2], sut)
         with assert_not_reactor_called(sut):
             reactive_value.react.trigger()
 
@@ -444,7 +445,7 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut.remove(reactive_value)
-        self.assertEquals([], sut)
+        self.assertEqual([], sut)
         with assert_not_reactor_called(sut):
             reactive_value.react.trigger()
 
@@ -453,28 +454,28 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut.reverse()
-        self.assertEquals([3, 2, 1], sut)
+        self.assertEqual([3, 2, 1], sut)
 
     def test_sort(self) -> None:
         sut = ReactiveList([3, 2, 1])
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut.sort()
-        self.assertEquals([1, 2, 3], sut)
+        self.assertEqual([1, 2, 3], sut)
 
     def test_sort_with_key(self) -> None:
         sut = ReactiveList(['xc', 'yb', 'za'])
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut.sort(key=lambda x: x[1])
-        self.assertEquals(['za', 'yb', 'xc'], sut)
+        self.assertEqual(['za', 'yb', 'xc'], sut)
 
     def test_sort_with_reversed(self) -> None:
         sut = ReactiveList([1, 2, 3])
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut.sort(reverse=True)
-        self.assertEquals([3, 2, 1], sut)
+        self.assertEqual([3, 2, 1], sut)
 
     def test_add(self) -> None:
         reactive_value = _Reactive()
@@ -483,7 +484,7 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_not_reactor_called(sut):
                 new_sut = sut + other
-        self.assertEquals([reactive_value, 1, 2], new_sut)
+        self.assertEqual([reactive_value, 1, 2], new_sut)
         with assert_reactor_called(new_sut):
             reactive_value.react.trigger()
 
@@ -499,18 +500,18 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 del sut[0]
-        self.assertEquals([], sut)
-        self.assertEquals([], reactive_value.react._reactors)
+        self.assertEqual([], sut)
+        self.assertEqual([], reactive_value.react._reactors)
 
     def test_eq(self) -> None:
         sut = ReactiveList([1, 2])
         with assert_in_scope(sut):
-            self.assertEquals([1, 2], sut)
+            self.assertEqual([1, 2], sut)
 
     def test_getitem(self) -> None:
         sut = ReactiveList([1, 2])
         with assert_in_scope(sut):
-            self.assertEquals(2, sut[1])
+            self.assertEqual(2, sut[1])
 
     def test_iadd(self) -> None:
         reactive_value1 = _Reactive()
@@ -519,7 +520,7 @@ class ReactiveListTest(TestCase):
         with assert_in_scope(sut):
             with assert_reactor_called(sut):
                 sut += [reactive_value1, reactive_value2]
-        self.assertEquals([1, 2, reactive_value1, reactive_value2], sut)
+        self.assertEqual([1, 2, reactive_value1, reactive_value2], sut)
         with assert_reactor_called(sut):
             reactive_value1.react.trigger()
         with assert_reactor_called(sut):
@@ -532,8 +533,7 @@ class ReactiveListTest(TestCase):
         with assert_in_scope(sut):
             with assert_reactor_called(sut):
                 sut *= 2
-        self.assertEquals([reactive_value1, reactive_value2,
-                           reactive_value1, reactive_value2], sut)
+        self.assertEqual([reactive_value1, reactive_value2, reactive_value1, reactive_value2], sut)
         with assert_reactor_called(sut):
             reactive_value1.react.trigger()
         with assert_reactor_called(sut):
@@ -542,12 +542,12 @@ class ReactiveListTest(TestCase):
     def test_iter(self) -> None:
         sut = ReactiveList([1, 2])
         with assert_in_scope(sut):
-            self.assertEquals([1, 2], list(iter(sut)))
+            self.assertEqual([1, 2], list(iter(sut)))
 
     def test_len(self) -> None:
         sut = ReactiveList([1, 2])
         with assert_in_scope(sut):
-            self.assertEquals(2, len(sut))
+            self.assertEqual(2, len(sut))
 
     def test_mul(self) -> None:
         reactive_value1 = _Reactive()
@@ -556,8 +556,7 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_not_reactor_called(sut):
                 new_sut = sut * 2
-        self.assertEquals([reactive_value1, reactive_value2,
-                           reactive_value1, reactive_value2], new_sut)
+        self.assertEqual([reactive_value1, reactive_value2, reactive_value1, reactive_value2], new_sut)
         with assert_reactor_called(new_sut):
             reactive_value1.react.trigger()
         with assert_reactor_called(new_sut):
@@ -566,12 +565,12 @@ class ReactiveListTest(TestCase):
     def test_ne(self) -> None:
         sut = ReactiveList([1, 2])
         with assert_in_scope(sut):
-            self.assertNotEquals([2, 1], sut)
+            self.assertNotEqual([2, 1], sut)
 
     def test_reversed(self) -> None:
         sut = ReactiveList([1, 2])
         with assert_in_scope(sut):
-            self.assertEquals([2, 1], list(reversed(sut)))
+            self.assertEqual([2, 1], list(reversed(sut)))
 
     def test_rmul(self) -> None:
         reactive_value1 = _Reactive()
@@ -580,8 +579,7 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_not_reactor_called(sut):
                 new_sut = 2 * sut
-        self.assertEquals([reactive_value1, reactive_value2,
-                           reactive_value1, reactive_value2], new_sut)
+        self.assertEqual([reactive_value1, reactive_value2, reactive_value1, reactive_value2], new_sut)
         with assert_reactor_called(new_sut):
             reactive_value1.react.trigger()
         with assert_reactor_called(new_sut):
@@ -593,7 +591,7 @@ class ReactiveListTest(TestCase):
         with assert_scope_empty():
             with assert_reactor_called(sut):
                 sut[1] = reactive_value
-        self.assertEquals(reactive_value, sut[1])
+        self.assertEqual(reactive_value, sut[1])
         with assert_reactor_called(sut):
             reactive_value.react.trigger()
 
